@@ -1,14 +1,12 @@
 package Dist::Zilla::Plugin::AlienBuild;
 
-use strict;
-use warnings;
 use 5.014;
 use Moose;
 use List::Util qw( first );
 use Path::Tiny qw( path );
 
 # ABSTRACT: Use Alien::Build with Dist::Zilla
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -32,7 +30,6 @@ sub register_prereqs
 
   my $prereqs = $self->zilla->prereqs->as_string_hash;
 
-  $DB::single = 1;  
   foreach my $phase (keys %$prereqs)
   {
     foreach my $type (keys %{ $prereqs->{$phase} })
@@ -159,6 +156,8 @@ sub metadata {
   { dynamic_config => 1 };
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -173,7 +172,7 @@ Dist::Zilla::Plugin::AlienBuild - Use Alien::Build with Dist::Zilla
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -199,7 +198,7 @@ requires.
 
 =item adjusts Makefile.PL
 
-Adjusts your C<Makefile.Pl> to use L<Alien::Build::MM>.  If you are using
+Adjusts your C<Makefile.PL> to use L<Alien::Build::MM>.  If you are using
 L<ExtUtils::MakeMaker>.
 
 =item sets the mb_class for Build.PL
@@ -215,7 +214,8 @@ Which are used by most L<Alien::Build> based L<Alien> distributions.
 
 =head1 SEE ALSO
 
-L<Alien::Build>, L<alienfile>, L<Alien::Base>, L<Alien::Build::MM>, L<Alien::Build::MB>
+L<Alien::Build>, L<alienfile>, L<Alien::Base>, L<Alien::Build::MM>, L<Alien::Build::MB>,
+L<Dist::Zilla::Plugin::AlienBase::Doc>
 
 =head1 AUTHOR
 
